# AsroNLP

AsroNLP is a Python library for processing and analyzing text in the Indonesian language, focusing on sentiment analysis.

## Installation

Run the following command to install:

```bash
pip install AsroNLP==0.1.8
```
